@@ -317,8 +317,9 @@ public class DriveUtils {
      * @return <code>true</code> if the exception indicates a failed saved exception, <code>false</code>, otherwise
      */
     public static boolean indicatesFailedSave(OXException e) {
-        return "IFO-0100".equals(e.getErrorCode()) || "IFO-2103".equals(e.getErrorCode()) ||
-            "FLD-0092".equals(e.getErrorCode()) || "FLD-0064".equals(e.getErrorCode()) || "FLD-1014".equals(e.getErrorCode()) || FileStorageExceptionCodes.DENIED_MIME_TYPE.equals(e);
+        return "IFO-0100".equals(e.getErrorCode()) || "IFO-2103".equals(e.getErrorCode()) || "RDB-0002".equals(e.getErrorCode()) ||
+            "FLD-0092".equals(e.getErrorCode()) || "FLD-0064".equals(e.getErrorCode()) || "FLD-1014".equals(e.getErrorCode()) ||
+            FileStorageExceptionCodes.DENIED_MIME_TYPE.equals(e);
     }
 
     /**
@@ -388,7 +389,22 @@ public class DriveUtils {
      * @return <code>true</code> if the session belongs to a known drive client, <code>false</code>, otherwise
      */
     public static boolean isDriveSession(Session session) {
-        return null != session && false == DriveClientType.UNKNOWN.equals(DriveClientType.parse(session.getClient()));
+        return null != session && false == DriveClientType.UNKNOWN.equals(DriveClientType.parse(getClientSafe(session)));
+    }
+
+    /**
+     * Retrieves the session-associated client identifier.
+     *
+     * @param session The session to retrieve from
+     * @return The client identifier or <code>null</code>
+     */
+    private static String getClientSafe(Session session) {
+        try {
+            return session.getClient();
+        } catch (Exception e) {
+            // Apparently client cannot be determined
+            return null;
+        }
     }
 
     /**
@@ -508,10 +524,11 @@ public class DriveUtils {
              * MIN_FOLDER_ID = 20
              * SYSTEM_USER_INFOSTORE_FOLDER_ID = 10
              * SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID = 15
+             * VIRTUAL_LIST_INFOSTORE_FOLDER_ID = 14
              */
             try {
                 int numericalID = Integer.parseInt(folderID);
-                if (numericalID < 20 && numericalID != 10 && numericalID != 15) {
+                if (numericalID < 20 && numericalID != 10 && numericalID != 15 && numericalID != 14) {
                     return false;
                 }
             } catch (NumberFormatException e) {
@@ -597,4 +614,4 @@ public class DriveUtils {
         super();
     }
 
-}
\ No newline at end of file
+}
