@@ -241,7 +241,7 @@ public class DriveServiceImpl implements DriveService {
                 }
                 int touched = driveSession.getChecksumStore().touchDirectoryChecksums(directoryChecksums);
                 driveSession.trace("Successfully touched " + touched + " stored directory checksums.");
-                TempCleaner.cleanUpIfNeeded(driveSession);
+                TempCleaner.cleanUpIfNeeded(driveSession, false);
             }
             /*
              * check (soft) version restrictions
@@ -384,7 +384,8 @@ public class DriveServiceImpl implements DriveService {
         IntermediateSyncResult<FileVersion> syncResult = new IntermediateSyncResult<FileVersion>();
         File createdFile = null;
         try {
-            createdFile = new UploadHelper(syncSession).perform(path, originalVersion, newVersion, uploadStream, DriveUtils.checkContentType(contentType), offset, totalLength, created, modified);
+            createdFile = new UploadHelper(syncSession).perform(
+                path, originalVersion, newVersion, uploadStream, DriveUtils.checkContentType(contentType), offset, totalLength, created, modified);
         } catch (OXException e) {
             if ("FLS-0022".equals(e.getErrorCode())) {
                 // The connected client closed the connection unexpectedly
@@ -396,6 +397,7 @@ public class DriveServiceImpl implements DriveService {
                 e.getMessage(), syncSession, path, originalVersion, newVersion, offset, totalLength, e);
             if (DriveUtils.indicatesQuotaExceeded(e)) {
                 syncResult.addActionsForClient(DriveUtils.handleQuotaExceeded(syncSession, e, path, originalVersion, newVersion));
+                TempCleaner.cleanUpIfNeeded(syncSession, true);
             } else if (DriveUtils.indicatesLockedContents(e)) {
                 syncResult.addActionsForClient(DriveUtils.handleLockedContents(syncSession, e, path, originalVersion, newVersion));
             } else if (DriveUtils.indicatesFailedSave(e)) {
@@ -666,4 +668,4 @@ public class DriveServiceImpl implements DriveService {
         return DriveUtilityImpl.getInstance();
     }
 
-}
\ No newline at end of file
+}
