@@ -51,6 +51,7 @@ package com.openexchange.drive.json.osgi;
 
 import org.osgi.framework.ServiceReference;
 import org.osgi.util.tracker.ServiceTrackerCustomizer;
+import com.openexchange.ajax.requesthandler.BodyParser;
 import com.openexchange.ajax.requesthandler.osgiservice.AJAXModuleActivator;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
@@ -63,6 +64,7 @@ import com.openexchange.drive.json.LongPollingListenerFactory;
 import com.openexchange.drive.json.action.DriveActionFactory;
 import com.openexchange.drive.json.internal.ListenerRegistrar;
 import com.openexchange.drive.json.internal.Services;
+import com.openexchange.drive.json.internal.UploadActionBodyParser;
 import com.openexchange.drive.json.listener.BlockingListenerFactory;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.share.ShareService;
@@ -101,6 +103,7 @@ public class DriveJsonActivator extends AJAXModuleActivator {
         getService(DriveEventService.class).registerPublisher(ListenerRegistrar.getInstance());
         track(LongPollingListenerFactory.class, new ServiceTrackerCustomizer<LongPollingListenerFactory, LongPollingListenerFactory>() {
 
+            @SuppressWarnings("synthetic-access")
             @Override
             public LongPollingListenerFactory addingService(ServiceReference<LongPollingListenerFactory> serviceReference) {
                 LongPollingListenerFactory service = context.getService(serviceReference);
@@ -118,6 +121,7 @@ public class DriveJsonActivator extends AJAXModuleActivator {
                 // nothing to do
             }
 
+            @SuppressWarnings("synthetic-access")
             @Override
             public void removedService(ServiceReference<LongPollingListenerFactory> serviceReference, LongPollingListenerFactory service) {
                 try {
@@ -138,12 +142,16 @@ public class DriveJsonActivator extends AJAXModuleActivator {
             LOG.info("Registering blocking long polling listener factory...");
             registerService(LongPollingListenerFactory.class, new BlockingListenerFactory());
         }
+        registerService(BodyParser.class, UploadActionBodyParser.getInstance());
     }
 
     @Override
     protected void stopBundle() throws Exception {
         LOG.info("stopping bundle: \"com.openexchange.drive.json\"");
-        getService(DriveEventService.class).unregisterPublisher(ListenerRegistrar.getInstance());
+        DriveEventService driveEventService = getService(DriveEventService.class);
+        if (null != driveEventService) {
+            driveEventService.unregisterPublisher(ListenerRegistrar.getInstance());
+        }
         Services.set(null);
         super.stopBundle();
     }
