@@ -49,7 +49,42 @@
 
 package com.openexchange.drive;
 
-import static com.openexchange.drive.DriveExceptionMessages.*;
+import static com.openexchange.drive.DriveExceptionMessages.CLIENT_OUTDATED_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.CLIENT_VERSION_UPDATE_AVAILABLE_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.CONFLICTING_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.CONFLICTING_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.DIRECTORYVERSION_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.DIRECTORY_ALREADY_EXISTS_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.FILEVERSION_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.FILE_ALREADY_EXISTS_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.FILE_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.IGNORED_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.IGNORED_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_DIRECTORYVERSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_FILEVERSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_FILE_OFFSET_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.INVALID_PATTERN_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.LEVEL_CONFLICTING_FILENAME_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.LEVEL_CONFLICTING_PATH_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.LONG_POLLING_NOT_AVAILABLE_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.METDATA_PARSE_ERROR_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NOT_SYNCHRONIZABLE_DIRECTORY_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_CREATE_DIRECTORY_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_CREATE_FILE_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_DELETE_DIRECTORY_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_DELETE_FILE_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.NO_MODIFY_FILE_PERMISSION_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.PATH_NOT_FOUND_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.QUOTA_REACHED_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.REPEATED_SYNC_PROBLEMS_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.SERVER_BUSY_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.TOKEN_ALREADY_REGISTERED_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.TOO_MANY_DIRECTORIES_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.TOO_MANY_FILES_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.UPLOADED_FILE_CHECKSUM_ERROR_MSG;
+import static com.openexchange.drive.DriveExceptionMessages.ZERO_BYTE_FILES_MSG;
 import com.openexchange.exception.Category;
 import com.openexchange.exception.DisplayableOXExceptionCode;
 import com.openexchange.exception.OXException;
